# encoding: utf8

from setuptools import setup


setup(
    name="sklego",
    version="0.0",
    description="a collection of lego bricks for scikit-learn pipelines",
    author="Vincent D. Warmerdam & Matthijs Brouns",
    url="https://scikit-lego.readthedocs.io/en/latest/",
    long_description='''Use `scikit-lego <https://pypi.python.org/pypi/scikit-lego/>`_ instead.''',
    install_requires=["scikit-lego"],
)


